@@ -18,9 +18,7 @@
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 
-"""
-Application route handlers.
-"""
+"""Application route handlers."""
 
 import logging
 import urllib
@@ -28,12 +26,10 @@ from io import BytesIO
 
 import cachetools
 import requests
+import validata_core
 from flasgger import swag_from
 from flask import request
-
-import tabulator
-import validata_core
-from validata_core.source_helpers import build_tabulator_params
+from validata_core.helpers import FileContentValidataResource, URLValidataResource
 
 from . import app, config
 from .json_errors import abort_json, make_json_response
@@ -48,111 +44,85 @@ log = logging.getLogger(__name__)
 
 
 def bytes_data(f):
-    """Gets bytes data from Werkzeug FileStorage instance"""
+    """Get bytes data from Werkzeug FileStorage instance."""
     iob = BytesIO()
     f.save(iob)
     iob.seek(0)
     return iob.getvalue()
 
 
-@app.route('/')
+@app.route("/")
 def index():
+    """Home."""
     apidocs_href = "{}/apidocs".format(config.SCRIPT_NAME)
     apidocs_url = urllib.parse.urljoin(request.url, apidocs_href)
-    return make_json_response({
-        "apidocs_href": apidocs_href,
-        "message": "This is the home page of Validata Web API. Its documentation is here: {}".format(apidocs_url)
-    }, args=None)
+    return make_json_response(
+        {
+            "apidocs_href": apidocs_href,
+            "message": (
+                "This is the home page of Validata Web API. "
+                f"Its documentation is here: {apidocs_url}"
+            ),
+        },
+        args=None,
+    )
 
 
 specs_dict = {
-    'get': {
-        'summary': 'Validate a tabular file from its URL',
-        'parameters': [
+    "get": {
+        "summary": "Validate a tabular file from its URL",
+        "parameters": [
             {
-                'name': 'schema',
-                'in': 'query',
-                'type': 'string',
-                'format': 'url',
-                'description': 'URL of schema to use for validation',
-                'example': 'https://git.opendatafrance.net/scdl/deliberations/raw/master/schema.json',
-                'required': True
+                "name": "schema",
+                "in": "query",
+                "type": "string",
+                "format": "url",
+                "description": "URL of schema to use for validation",
+                "example": "https://git.opendatafrance.net/scdl/deliberations/raw/master/schema.json",
+                "required": True,
             },
             {
-                'name': 'url',
-                'in': 'query',
-                'type': 'string',
-                'format': 'url',
-                'description': 'URL of tabular file to validate',
-                'example': 'https://git.opendatafrance.net/scdl/deliberations/raw/v2.0/examples/Deliberations_ok.csv',
-                'required': True
+                "name": "url",
+                "in": "query",
+                "type": "string",
+                "format": "url",
+                "description": "URL of tabular file to validate",
+                "example": "https://git.opendatafrance.net/scdl/deliberations/raw/v2.0/examples/Deliberations_ok.csv",
+                "required": True,
             },
-            {
-                'name': 'repair',
-                'in': 'query',
-                'type': 'boolean',
-                'default': False,
-                'description': 'Preprocess file structure prior to content validation',
-                'example': False,
-                'required': False
-            }
         ],
-        'produces': [
-            'application/json'
-        ]
+        "produces": ["application/json"],
     },
-    'post': {
-        'summary': 'Validate an uploaded tabular file',
-        'parameters': [
+    "post": {
+        "summary": "Validate an uploaded tabular file",
+        "parameters": [
             {
-                'name': 'schema',
-                'in': 'formData',
-                'type': 'string',
-                'format': 'url',
-                'description': 'URL of schema to use for validation',
-                'example': 'https://git.opendatafrance.net/scdl/deliberations/raw/master/schema.json',
-                'required': True,
+                "name": "schema",
+                "in": "formData",
+                "type": "string",
+                "format": "url",
+                "description": "URL of schema to use for validation",
+                "example": "https://git.opendatafrance.net/scdl/deliberations/raw/master/schema.json",
+                "required": True,
             },
             {
-                'name': 'file',
-                'in': 'formData',
-                'type': 'file',
-                'description': 'The file to upload',
-                'required': True,
+                "name": "file",
+                "in": "formData",
+                "type": "file",
+                "description": "The file to upload",
+                "required": True,
             },
-            {
-                'name': 'repair',
-                'in': 'formData',
-                'type': 'boolean',
-                'default': False,
-                'description': 'Preprocess file structure prior to content validation',
-                'example': False,
-                'required': False,
-            }
         ],
-        'consumes': [
-            'multipart/form-data'
-        ],
-        'produces': [
-            'application/json'
-        ]
+        "consumes": ["multipart/form-data"],
+        "produces": ["application/json"],
     },
-    'responses': {
-        '200': {
-            'description': 'Validation report',
-            'schema': {
-                'type': 'object',
-                'required': [
-                    '_meta',
-                    "schema",
-                    'report'
-                ]
-            },
-            'examples': [
+    "responses": {
+        "200": {
+            "description": "Validation report",
+            "schema": {"type": "object", "required": ["_meta", "schema", "report"]},
+            "examples": [
                 {
-                    "_meta": {
-                        "version": "0.2.0"
-                    },
+                    "_meta": {"version": "0.2.0"},
                     "schema": {},
                     "report": {
                         "error-count": 1,
@@ -168,9 +138,9 @@ specs_dict = {
                                         "message": None,
                                         "message-data": {
                                             "detected": ";",
-                                            "expected": ","
+                                            "expected": ",",
                                         },
-                                        "row-number": None
+                                        "row-number": None,
                                     },
                                     {
                                         "code": "compare-columns-value",
@@ -181,10 +151,10 @@ specs_dict = {
                                             "column2": "DELIB_DATE",
                                             "op": "supérieure ou égale",
                                             "value1": "2017-02-03",
-                                            "value2": "2017-10-15"
+                                            "value2": "2017-10-15",
                                         },
-                                        "row-number": 2
-                                    }
+                                        "row-number": 2,
+                                    },
                                 ],
                                 "format": "inline",
                                 "headers": [
@@ -204,108 +174,85 @@ specs_dict = {
                                     "VOTE_POUR",
                                     "VOTE_CONTRE",
                                     "VOTE_ABSTENTION",
-                                    "DELIB_URL"
+                                    "DELIB_URL",
                                 ],
                                 "row-count": 2,
                                 "schema": "table-schema",
                                 "source": "inline",
                                 "time": 0.006,
-                                "valid": False
+                                "valid": False,
                             }
                         ],
                         "time": 0.014,
                         "valid": False,
-                        "warnings": []
-                    }
-                }
-            ]
-        },
-        '400': {
-            'description': 'Error',
-            'schema': {
-                'type': 'object',
-                'required': [
-                    '_meta',
-                    'message'
-                ]
-            },
-            'examples': [
-                {
-                    "_meta": {
-                        "version": "0.2.0"
+                        "warnings": [],
                     },
-                    "message": "Unsupported format error"
                 }
-            ]
-        }
-    }
+            ],
+        },
+        "400": {
+            "description": "Error",
+            "schema": {"type": "object", "required": ["_meta", "message"]},
+            "examples": [
+                {"_meta": {"version": "0.2.0"}, "message": "Unsupported format error"}
+            ],
+        },
+    },
 }
 
 
 @cachetools.cached(cachetools.TTLCache(SCHEMA_CACHE_SIZE, SCHEMA_CACHE_TTL))
 def download_schema(schema_url):
     """Download schema by its given url"""
-
     return requests.get(schema_url).json()
 
 
-@app.route('/validate', methods={"GET", "POST"})
+@app.route("/validate", methods={"GET", "POST"})
 @swag_from(specs_dict)
 def validate():
-    # Extract parameters
+    """Validate endpoint."""
 
-    if request.method == 'GET':
+    if request.method == "GET":
         args = {
-            'schema': request.args.get('schema'),
-            'url': request.args.get('url'),
-            'repair': request.args.get('repair') or False,
+            "schema": request.args.get("schema"),
+            "url": request.args.get("url"),
         }
     else:
-        assert request.method == 'POST', request.method
+        assert request.method == "POST", request.method
         args = {
-            'schema': request.form.get('schema'),
-            'repair': request.form.get('repair') or False,
+            "schema": request.form.get("schema"),
         }
 
-    if not args['schema']:
+    if not args["schema"]:
         abort_json(400, args, 'Missing or empty "schema" parameter')
 
     # Download Schema from URL to get control on cache
     # schema json dict is passed to validate function as a dict
     try:
-        schema_dict = download_schema(args['schema'])
-
+        schema_dict = download_schema(args["schema"])
     except Exception as err:
         abort_json(400, {}, str(err))
 
-    if request.method == 'GET':
+    validata_resource = None
+
+    if request.method == "GET":
         # URL validation
-        if not args['url']:
+        if not args["url"]:
             abort_json(400, args, 'Missing or empty "url" parameter')
+        validata_resource = URLValidataResource(args["url"])
 
-        params = build_tabulator_params('url', args['url'], args['url'])
-
-    elif request.method == 'POST':
+    elif request.method == "POST":
         # Uploaded file validation
-        f = request.files.get('file')
+        f = request.files.get("file")
         if f is None:
             abort_json(400, args, 'Missing or empty "file" parameter')
+        validata_resource = FileContentValidataResource(f.filename, bytes_data(f))
 
-        params = build_tabulator_params('file', f.filename, bytes_data(f))
-
-    try:
-        goodtables_report = validata_core.validate(
-            schema=schema_dict, force_strings=True, with_repair=args['repair'], **params)
-    except tabulator.exceptions.FormatError as exc:
-        log.exception("Error validating %r with %r", args['schema'], params)
-        abort_json(400, args, str(exc))
+    header, rows = validata_resource.extract_tabular_data()
+    validation_report = validata_core.validate([header] + rows, schema_dict)
 
     body = {
-        'report': goodtables_report,
+        "report": validation_report.to_dict(),
     }
 
-    # badge info
-    if config.BADGE_CONFIG is not None:
-        body["badge"] = validata_core.compute_badge(goodtables_report, config.BADGE_CONFIG)
-
     return make_json_response(body, args)
